@@ -1,16 +1,15 @@
 package Regexp::Pattern;
 
-our $DATE = '2016-09-12'; # DATE
-our $VERSION = '0.1.0'; # VERSION
+our $DATE = '2016-09-13'; # DATE
+our $VERSION = '0.1.1'; # VERSION
 
 use strict 'subs', 'vars';
-use warnings;
+#use warnings;
 
 use Exporter qw(import);
 our @EXPORT = qw(re);
-our @EXPORT_OK = qw(get_re_pat list_re_pats list_re_pat_modules re);
 
-sub get_re_pat {
+sub re {
     my $name = shift;
 
     my ($mod, $patname) = $name =~ /(.+)::(.+)/
@@ -34,17 +33,6 @@ sub get_re_pat {
     }
 }
 
-sub list_re_pats {
-    die "Not yet implemented";
-}
-
-sub list_re_pat_modules {
-    die "Not yet implemented";
-}
-
-*re = \&get_re_pat;
-
-
 1;
 # ABSTRACT: Collection of regexp patterns
 
@@ -60,7 +48,7 @@ Regexp::Pattern - Collection of regexp patterns
 
 =head1 VERSION
 
-This document describes version 0.1.0 of Regexp::Pattern (from Perl distribution Regexp-Pattern), released on 2016-09-12.
+This document describes version 0.1.1 of Regexp::Pattern (from Perl distribution Regexp-Pattern), released on 2016-09-13.
 
 =head1 SYNOPSIS
 
@@ -142,7 +130,8 @@ simply data that can be grabbed using a normal means, e.g.:
  say "Input does not match blah"
      unless $input =~ /\A$Regexp::Pattern::Example::RE{re1}{pat}\z/;
 
-C<Regexp::Pattern> (this module) also provides C<re()> function
+C<Regexp::Pattern> (this module) also provides C<re()> function to help retrieve
+the regexp pattern.
 
 =head1 SPECIFICATION VERSION
 
@@ -150,13 +139,14 @@ C<Regexp::Pattern> (this module) also provides C<re()> function
 
 =head1 FUNCTIONS
 
-=head2 get_re_pat
+=head2 re
 
-Get a regexp pattern by name from a C<Regexp::Pattern::*> module.
+Exported by default. Get a regexp pattern by name from a C<Regexp::Pattern::*>
+module.
 
 Syntax:
 
- get_re_pat($name[, \%args ]) => $re
+ re($name[, \%args ]) => $re
 
 C<$name> is I<MODULE_NAME::PATTERN_NAME> where I<MODULE_NAME> is name of a
 C<Regexp::Pattern::*> module without the C<Regexp::Pattern::> prefix and
@@ -165,14 +155,6 @@ I<PATTERN_NAME> is a key to the C<%RE> package global hash in the module.
 Die when pattern by name C<$name> cannot be found (either the module cannot be
 loaded or the pattern with that name is not found in the module).
 
-=head2 list_re_pat_modules
-
-=head2 list_re_pats
-
-=head2 re
-
-Shortcut for L</"get_re_pat">. Exported by default.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Regexp-Pattern>.
@@ -193,12 +175,14 @@ feature.
 
 L<Regexp::Common>. Regexp::Pattern is an alternative to Regexp::Common.
 Regexp::Pattern offers simplicity and lower startup overhead. Instead of a magic
-hash, you query available regexes using C<get_re_pat> (shortcut C<re>) and
-C<list_re_pats> functions.
+hash, you retrieve available regexes from normal data structure or via the
+provided C<re()> function.
 
 L<Regexp::Common::RegexpPattern>, a bridge module to use patterns in
 C<Regexp::Pattern::*> modules via Regexp::Common.
 
+L<App::RegexpPatternUtils>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
