@@ -1,7 +1,7 @@
 package Regexp::Pattern::Example;
 
-our $DATE = '2016-09-12'; # DATE
-our $VERSION = '0.1.0'; # VERSION
+our $DATE = '2016-09-13'; # DATE
+our $VERSION = '0.1.1'; # VERSION
 
 # BEGIN_BLOCK: def
 
@@ -65,7 +65,52 @@ Regexp::Pattern::Example - An example Regexp::Pattern::* module
 
 =head1 VERSION
 
-This document describes version 0.1.0 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2016-09-12.
+This document describes version 0.1.1 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2016-09-13.
+
+=head1 SYNOPSIS
+
+ use Regexp::Pattern; # exports re()
+ my $re = re("Example::re1");
+
+=head1 DESCRIPTION
+
+L<Regexp::Pattern> is a convention for organizing reusable regex patterns.
+
+=head1 PATTERNS
+
+=over
+
+=item * re1
+
+=item * re2
+
+This is regexp for blah.
+
+A longer description.
+
+
+=item * re3
+
+This is a regexp for blah blah.
+
+...
+
+
+This is a dynamic pattern which will be generated on-demand.
+
+The following arguments are available to customize the generated pattern:
+
+=over
+
+=item * variant
+
+Choose variant.
+
+=back
+
+
+
+=back
 
 =head1 HOMEPAGE
 
